/***************************************************************************
 *   Copyright (C) 2005 by Yuri Vatis   																								*
 *   vatis@tnt.uni-hannover.de																														*
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DISPLAY_H
#define DISPLAY_H

#include <QFile>
#include <QWidget>
#include <QPainter>

#include "global.h"

class Seqdis;
class TableYValues;
class Difference;
class MainWindow;
class QPushButton;
class QImage;

class TableYValues : public QWidget{
	Q_OBJECT
	public:
		TableYValues(QWidget * parent = 0, Qt::WFlags f = 0 );
		void setTable(uchar *, int posX, int posY, int imgWidth, int imgHeight, int curWindow);
		void paintEvent(QPaintEvent *);
	protected:
		virtual void closeEvent(QCloseEvent * e );
	private slots:
		void changeWhite_Color();
	private:
		int itemSizeX;
		int itemSizeY;
		int curValues[10][10];
		Seqdis *parent;
		QPushButton *WhiteColorButton;
		bool curWhiteColorState;			// false - White, true - Color
};


class Seqdis : public QWidget {
	public:
		Seqdis (QWidget *parent = 0, Qt::WFlags flags = 0);
		~Seqdis();

		int loadFile(QString fileName, int sX, int sY, int yuv);		// 1. or 2. file
		int  getTotalFrameNr() const;
		uchar* getYUVBuffer() const;
		int  getCurrentFrameNr() const;
		QImage getImage() const;
		void showFrameNr(int);
		void showNextFrame();
		void showPreviousFrame();
		void showFirstFrame();
		void showCurrentFrame();
		void setStop(int s);
		void setSize(int, int);
		void setStatusBarMessage(QString);
		void paintEvent(QPaintEvent *);
		TableYValues *YBlock;		// block with 10x10 Y-Values (incl. row and column)

		virtual void mouseReleaseEvent(QMouseEvent * e);

	protected:
		virtual void closeEvent(QCloseEvent * e );
	private:
		void convertFrame();
		QString getShortFileName(QString);

		int 				sizeX;
		int 				sizeY;
		int 				frequency;
		int 				format;					// 0 - y, 1- yuv
		QFile				file;
		int         total_frame_nr;	// total frame nr
		int 				cur_frame_nr;		// shows to the current frame to be displayed

		uchar      *rgbbuf;					// rgb-buffer
		uchar      *rgbbufdiff;			// rgb-buffer difference
		uchar      *yuvbuf;					// yuv-buffer
		int					yuvbuffersize;	// size of the yuv(y)-buffer
		QString			fullFileName;
		QString			shortFileName;
		QImage 		 *img;
		QPainter	  painter;
		MainWindow *parent;
		int					par;
};


class Difference : public QWidget{
	public:
		Difference(QWidget *parent = 0, Qt::WFlags flags = 0);
		void setSizeXY(int sX, int sY);
		void setFramesPointer(uchar *, uchar *);
		void showDifference(int log);
		void paintEvent(QPaintEvent *);
		QImage getImage() const;

	protected:
		virtual void mouseReleaseEvent(QMouseEvent*);
		virtual void closeEvent(QCloseEvent * e );

	private:
		void initLogTable();
		uchar *yuv1;
		uchar *yuv2;
		QImage *img;
		uchar *rgbbuf;
		int sizeX;
		int sizeY;
		double logNat_table[257];
		MainWindow *parent;
};

#endif
